EBXUpdate.RdThis function updates existing data rows of a code list stored in EBX5.
Requires that the EBX5 connection was configured using SetupEBXConnection.
EBXUpdate(branch, instance, folder, folder2 = "", table, data, connection = NA)
| branch | dataset branch |
|---|---|
| instance | dataset instance |
| folder | folder where the table is |
| folder2 | optional second level folder |
| table | ebx5 table name |
| data | a |
| connection | the result of |
boolean
The data columns provided must follow the code-list which is being updated.
All fiels of a primary key (usually the Identifier) must be present.
Using the SOAP-API the column names and tabe table name are not the label visible in EBX, but the name.
Requires that the EBX5 connection was configured using SetupEBXConnection.
Thomas Berger, thomas.berger@fao.org
Luis G. Silva e Silva, luis.silvaesilva@fao.org
if (FALSE) { cl_update <- data.frame( Identifier = c(999, 888), Acronym = 'TEST_ACRONYM', Folder = 'TESTFOLDER', Name = 'TEST_NAME', Branch = 'Fishery', Instance = 'Fishery') EBXUpdate(branch = 'Fishery', instance = 'Fishery', folder = 'Metadata', table = 'Test_table', data = cl_update) }